1.0.0 API documentation: matrix_double4x4.hpp Source File

| 1.0.0 API documentation

matrix_double4x4.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_mat4x4.hpp"
6
7 namespace glm
8 {
11
15 typedef mat<4, 4, double, defaultp> dmat4x4;
16
20 typedef mat<4, 4, double, defaultp> dmat4;
21
23 }//namespace glm
glm::dmat4
mat< 4, 4, double, defaultp > dmat4
4 columns of 4 components matrix of double-precision floating-point numbers.
Definition: matrix_double4x4.hpp:20
glm::dmat4x4
mat< 4, 4, double, defaultp > dmat4x4
4 columns of 4 components matrix of double-precision floating-point numbers.
Definition: matrix_double4x4.hpp:15